Skip to contents

Take the first column of a data.frame as row names and return the remaining columns as a matrix.

Usage

df2mtx(df)

Arguments

df

A data.frame.

Value

A matrix with row names taken from the first column.