Performs GO or KEGG GSEA using ranked gene statistics. This function dynamically loads clusterProfiler and annotation packages only when needed, making them optional dependencies.
Arguments
- df
A data frame containing ranking statistics and gene IDs.
- gene_col
Column storing gene IDs.
- stat_col
Column storing ranking values (e.g. log2FC).
- db
Database for GSEA:
"GO"or"KEGG".- ont
GO ontology ("BP","CC","MF","ALL").
- species
Species:
"human"or"mouse".- keyType
Gene ID type (default SYMBOL).
- qvalue_cutoff
Q-value filter.
- minGSSize
Minimum gene set size.
- maxGSSize
Maximum gene set size.
- pAdjustMethod
Multiple testing correction.
- eps
GSEA numeric convergence threshold.
- use_internal_data
whether using internal KEGG data
- seed
Random seed.